searchData={"items":[{"type":"module","title":"HipcallSMS","doc":"HipcallSMS is a unified SMS library for sending SMS messages through multiple providers.\n\nSupported providers:\n- Telnyx\n- Twilio\n- Iletimerkezi","ref":"HipcallSMS.html"},{"type":"module","title":"Configuration - HipcallSMS","doc":"You can configure providers in your `config.exs`:\n\n    config :hipcall_sms,\n      adapter: HipcallSMS.Adapters.Telnyx,\n      telnyx_api_key: {:system, \"TELNYX_API_KEY\"},\n      twilio_account_sid: {:system, \"TWILIO_ACCOUNT_SID\"},\n      twilio_auth_token: {:system, \"TWILIO_AUTH_TOKEN\"},\n      iletimerkezi_key: {:system, \"ILETIMERKEZI_KEY\"},\n      iletimerkezi_hash: {:system, \"ILETIMERKEZI_HASH\"}","ref":"HipcallSMS.html#module-configuration"},{"type":"module","title":"Usage - HipcallSMS","doc":"# Create and send an SMS\n    sms =\n      HipcallSMS.SMS.new()\n      |> HipcallSMS.SMS.from(\"+15551234567\")\n      |> HipcallSMS.SMS.to(\"+15555555555\")\n      |> HipcallSMS.SMS.text(\"Hello from HipcallSMS!\")\n\n    HipcallSMS.deliver(sms)\n\n    # Or with configuration override\n    config = [\n      adapter: HipcallSMS.Adapters.Twilio,\n      account_sid: \"your_account_sid\",\n      auth_token: \"your_auth_token\"\n    ]\n\n    HipcallSMS.deliver(sms, config)\n\n    # Quick send\n    HipcallSMS.send_sms(\"+15551234567\", \"+15555555555\", \"Hello!\")\n\n    # Check account balance\n    {:ok, balance} = HipcallSMS.get_balance()\n    IO.puts(\"Current balance: \" <> balance.balance <> \" \" <> balance.currency)","ref":"HipcallSMS.html#module-usage"},{"type":"type","title":"HipcallSMS.config/0","doc":"","ref":"HipcallSMS.html#t:config/0"},{"type":"function","title":"HipcallSMS.deliver/2","doc":"Delivers an SMS using the configured adapter.\n\nThis function takes an SMS struct and optional configuration to send the message\nthrough the specified provider. If no configuration is provided, it uses the\napplication configuration.","ref":"HipcallSMS.html#deliver/2"},{"type":"function","title":"Parameters - HipcallSMS.deliver/2","doc":"- `sms` - A `HipcallSMS.SMS` struct containing the message details\n- `config` - Optional keyword list to override adapter configuration","ref":"HipcallSMS.html#deliver/2-parameters"},{"type":"function","title":"Returns - HipcallSMS.deliver/2","doc":"- `{:ok, response}` - Success with provider response containing message ID and status\n- `{:error, reason}` - Failure with error details","ref":"HipcallSMS.html#deliver/2-returns"},{"type":"function","title":"Examples - HipcallSMS.deliver/2","doc":"# Basic usage with application config\n    sms = SMS.new(from: \"+15551234567\", to: \"+15555555555\", text: \"Hello!\")\n    {:ok, response} = HipcallSMS.deliver(sms)\n    # => {:ok, %{id: \"msg_123\", status: \"queued\", provider: \"twilio\"}}\n\n    # With configuration override for Twilio\n    config = [\n      adapter: HipcallSMS.Adapters.Twilio,\n      account_sid: \"ACxxxxx\",\n      auth_token: \"your_auth_token\"\n    ]\n    {:ok, response} = HipcallSMS.deliver(sms, config)\n\n    # With configuration override for Telnyx\n    config = [\n      adapter: HipcallSMS.Adapters.Telnyx,\n      api_key: \"your_api_key\"\n    ]\n    {:ok, response} = HipcallSMS.deliver(sms, config)\n\n    # With configuration override for Iletimerkezi\n    config = [\n      adapter: HipcallSMS.Adapters.Iletimerkezi,\n      key: \"your_key\",\n      hash: \"your_hash\"\n    ]\n    {:ok, response} = HipcallSMS.deliver(sms, config)","ref":"HipcallSMS.html#deliver/2-examples"},{"type":"function","title":"Error Handling - HipcallSMS.deliver/2","doc":"case HipcallSMS.deliver(sms) do\n      {:ok, response} ->\n        IO.puts(\"Message sent with ID: \" <> response.id)\n      {:error, %{status: 401}} ->\n        IO.puts(\"Authentication failed\")\n      {:error, %{status: 400, body: body}} ->\n        IO.puts(\"Bad request: \" <> inspect(body))\n      {:error, reason} ->\n        IO.puts(\"Failed to send: \" <> inspect(reason))\n    end","ref":"HipcallSMS.html#deliver/2-error-handling"},{"type":"type","title":"HipcallSMS.delivery_result/0","doc":"","ref":"HipcallSMS.html#t:delivery_result/0"},{"type":"function","title":"HipcallSMS.get_balance/1","doc":"Gets the account balance from the configured SMS provider.\n\nThis function retrieves the current account balance information from the provider's API.\nThe response format may vary between providers but will be normalized to include\ncommon balance information.","ref":"HipcallSMS.html#get_balance/1"},{"type":"function","title":"Parameters - HipcallSMS.get_balance/1","doc":"- `config` - Optional keyword list to override adapter configuration","ref":"HipcallSMS.html#get_balance/1-parameters"},{"type":"function","title":"Returns - HipcallSMS.get_balance/1","doc":"- `{:ok, balance_info}` - Success with balance information map\n- `{:error, reason}` - Failure with error details","ref":"HipcallSMS.html#get_balance/1-returns"},{"type":"function","title":"Examples - HipcallSMS.get_balance/1","doc":"# Get balance with application config\n    {:ok, balance} = HipcallSMS.get_balance()\n\n    # With Telnyx configuration override\n    config = [\n      adapter: HipcallSMS.Adapters.Telnyx,\n      api_key: \"your_api_key\"\n    ]\n    {:ok, balance} = HipcallSMS.get_balance(config)\n    # => {:ok, %{balance: \"300.00\", currency: \"USD\", credit_limit: \"100.00\", ...}}\n\n    # With Iletimerkezi configuration override\n    config = [\n      adapter: HipcallSMS.Adapters.Iletimerkezi,\n      key: \"your_key\",\n      hash: \"your_hash\"\n    ]\n    {:ok, balance} = HipcallSMS.get_balance(config)\n    # => {:ok, %{balance: \"0\", sms_balance: \"18343\", currency: \"TRY\", ...}}","ref":"HipcallSMS.html#get_balance/1-examples"},{"type":"function","title":"Error Handling - HipcallSMS.get_balance/1","doc":"case HipcallSMS.get_balance() do\n      {:ok, balance} ->\n        IO.puts(\"Current balance: \" <> balance.balance <> \" \" <> balance.currency)\n      {:error, %{status: 401}} ->\n        IO.puts(\"Authentication failed\")\n      {:error, %{status: 400, body: body}} ->\n        IO.puts(\"Bad request: \" <> inspect(body))\n      {:error, reason} ->\n        IO.puts(\"Failed to get balance: \" <> inspect(reason))\n    end","ref":"HipcallSMS.html#get_balance/1-error-handling"},{"type":"function","title":"HipcallSMS.send_sms/4","doc":"Quick function to send an SMS without creating an SMS struct first.\n\nThis is a convenience function that creates an SMS struct internally and\ndelivers it using the specified or configured adapter.","ref":"HipcallSMS.html#send_sms/4"},{"type":"function","title":"Parameters - HipcallSMS.send_sms/4","doc":"- `from` - The sender phone number (E.164 format recommended)\n- `to` - The recipient phone number (E.164 format recommended)\n- `text` - The message content\n- `config` - Optional keyword list to override adapter configuration","ref":"HipcallSMS.html#send_sms/4-parameters"},{"type":"function","title":"Returns - HipcallSMS.send_sms/4","doc":"- `{:ok, response}` - Success with provider response\n- `{:error, reason}` - Failure with error details","ref":"HipcallSMS.html#send_sms/4-returns"},{"type":"function","title":"Examples - HipcallSMS.send_sms/4","doc":"# Basic usage\n    {:ok, response} = HipcallSMS.send_sms(\"+15551234567\", \"+15555555555\", \"Hello!\")\n\n    # With Twilio configuration override\n    config = [\n      adapter: HipcallSMS.Adapters.Twilio,\n      account_sid: \"ACxxxxx\",\n      auth_token: \"your_auth_token\"\n    ]\n    {:ok, response} = HipcallSMS.send_sms(\"+15551234567\", \"+15555555555\", \"Hello!\", config)\n\n    # Sending a longer message\n    message = \"This is a longer SMS message that demonstrates sending multi-part messages through HipcallSMS.\"\n    {:ok, response} = HipcallSMS.send_sms(\"+15551234567\", \"+15555555555\", message)\n\n    # International numbers\n    {:ok, response} = HipcallSMS.send_sms(\"+442071234567\", \"+33123456789\", \"Hello from UK to France!\")","ref":"HipcallSMS.html#send_sms/4-examples"},{"type":"function","title":"Error Handling - HipcallSMS.send_sms/4","doc":"case HipcallSMS.send_sms(\"+15551234567\", \"+15555555555\", \"Hello!\") do\n      {:ok, response} ->\n        IO.puts(\"SMS sent successfully\")\n      {:error, reason} ->\n        IO.puts(\"Failed to send SMS\")\n    end","ref":"HipcallSMS.html#send_sms/4-error-handling"},{"type":"function","title":"HipcallSMS.version/0","doc":"Returns the current version of HipcallSMS.","ref":"HipcallSMS.html#version/0"},{"type":"function","title":"Examples - HipcallSMS.version/0","doc":"iex> HipcallSMS.version()\n    \"0.3.0\"","ref":"HipcallSMS.html#version/0-examples"},{"type":"behaviour","title":"HipcallSMS.Adapter","doc":"Specification of the SMS delivery adapter.\n\nThis module defines the behavior that all SMS adapters must implement and provides\nutility functions for configuration validation and dependency checking.","ref":"HipcallSMS.Adapter.html"},{"type":"behaviour","title":"Creating an Adapter - HipcallSMS.Adapter","doc":"To create a new SMS adapter, you need to implement the `HipcallSMS.Adapter` behavior\nand use the `__using__/1` macro to get default implementations of common functions.","ref":"HipcallSMS.Adapter.html#module-creating-an-adapter"},{"type":"behaviour","title":"Example - HipcallSMS.Adapter","doc":"defmodule MyApp.Adapters.CustomProvider do\n      use HipcallSMS.Adapter, required_config: [:api_key, :secret]\n\n      @impl HipcallSMS.Adapter\n      def deliver(%HipcallSMS.SMS{} = sms, config) do\n        # Implementation for sending SMS through your provider\n        {:ok, %{id: \"msg_123\", status: \"sent\"}}\n      end\n    end","ref":"HipcallSMS.Adapter.html#module-example"},{"type":"behaviour","title":"Configuration - HipcallSMS.Adapter","doc":"Adapters can specify required configuration keys that must be present when\ndelivering an SMS. The `validate_config/1` callback will automatically check\nfor these keys.","ref":"HipcallSMS.Adapter.html#module-configuration"},{"type":"behaviour","title":"Dependencies - HipcallSMS.Adapter","doc":"Adapters can also specify required dependencies that must be available at runtime.\nThis is useful for HTTP clients or other external libraries.","ref":"HipcallSMS.Adapter.html#module-dependencies"},{"type":"macro","title":"HipcallSMS.Adapter.__using__/1","doc":"Macro for implementing SMS adapters.\n\nThis macro provides default implementations for common adapter functions and\nsets up the required configuration and dependencies.","ref":"HipcallSMS.Adapter.html#__using__/1"},{"type":"macro","title":"Options - HipcallSMS.Adapter.__using__/1","doc":"- `:required_config` - List of atoms representing required configuration keys\n- `:required_deps` - List of modules or `{library, module}` tuples for required dependencies","ref":"HipcallSMS.Adapter.html#__using__/1-options"},{"type":"macro","title":"Examples - HipcallSMS.Adapter.__using__/1","doc":"# Basic adapter with API key requirement\n    use HipcallSMS.Adapter, required_config: [:api_key]\n\n    # Adapter with multiple config requirements\n    use HipcallSMS.Adapter, required_config: [:account_sid, :auth_token]\n\n    # Adapter with dependencies\n    use HipcallSMS.Adapter,\n      required_config: [:api_key],\n      required_deps: [Finch, Jason]","ref":"HipcallSMS.Adapter.html#__using__/1-examples"},{"type":"type","title":"HipcallSMS.Adapter.config/0","doc":"","ref":"HipcallSMS.Adapter.html#t:config/0"},{"type":"callback","title":"HipcallSMS.Adapter.deliver/2","doc":"Delivers a SMS with the given config.\n\nThis callback must be implemented by all adapters to handle the actual SMS delivery\nthrough the provider's API.","ref":"HipcallSMS.Adapter.html#c:deliver/2"},{"type":"callback","title":"Parameters - HipcallSMS.Adapter.deliver/2","doc":"- `sms` - The SMS struct containing message details\n- `config` - Configuration keyword list with provider-specific settings","ref":"HipcallSMS.Adapter.html#c:deliver/2-parameters"},{"type":"callback","title":"Returns - HipcallSMS.Adapter.deliver/2","doc":"- `{:ok, response}` - Success with provider response map\n- `{:error, reason}` - Failure with error details","ref":"HipcallSMS.Adapter.html#c:deliver/2-returns"},{"type":"callback","title":"Configuration Override - HipcallSMS.Adapter.deliver/2","doc":"Client library configuration can be overwritten at runtime by passing\na configuration map as the last argument. This is useful for multi-tenant\napplications or when you need to use different credentials per request.","ref":"HipcallSMS.Adapter.html#c:deliver/2-configuration-override"},{"type":"callback","title":"Examples - HipcallSMS.Adapter.deliver/2","doc":"# Basic delivery with application config\n    {:ok, response} = MyAdapter.deliver(sms, [])\n\n    # Delivery with runtime config override\n    config_override = [\n      adapter: HipcallSMS.Adapters.Twilio,\n      account_sid: \"ACxxxxx\",\n      auth_token: \"runtime_token\"\n    ]\n    {:ok, response} = MyAdapter.deliver(sms, config_override)","ref":"HipcallSMS.Adapter.html#c:deliver/2-examples"},{"type":"type","title":"HipcallSMS.Adapter.delivery_result/0","doc":"","ref":"HipcallSMS.Adapter.html#t:delivery_result/0"},{"type":"callback","title":"HipcallSMS.Adapter.get_balance/1","doc":"Gets the account balance from the SMS provider.\n\nThis callback retrieves the current account balance information from the provider's API.\nThe response format may vary between providers but should include balance information.","ref":"HipcallSMS.Adapter.html#c:get_balance/1"},{"type":"callback","title":"Parameters - HipcallSMS.Adapter.get_balance/1","doc":"- `config` - Configuration keyword list with provider-specific settings","ref":"HipcallSMS.Adapter.html#c:get_balance/1-parameters"},{"type":"callback","title":"Returns - HipcallSMS.Adapter.get_balance/1","doc":"- `{:ok, balance_info}` - Success with balance information map\n- `{:error, reason}` - Failure with error details","ref":"HipcallSMS.Adapter.html#c:get_balance/1-returns"},{"type":"callback","title":"Examples - HipcallSMS.Adapter.get_balance/1","doc":"# Get balance with application config\n    {:ok, balance} = MyAdapter.get_balance([])\n\n    # Get balance with runtime config override\n    config_override = [\n      adapter: HipcallSMS.Adapters.Telnyx,\n      api_key: \"runtime_api_key\"\n    ]\n    {:ok, balance} = MyAdapter.get_balance(config_override)","ref":"HipcallSMS.Adapter.html#c:get_balance/1-examples"},{"type":"function","title":"HipcallSMS.Adapter.get_config_value/2","doc":"Gets a configuration value from the application environment.\n\nThis function retrieves configuration values with support for system environment\nvariables and default fallbacks. It supports several configuration formats:\n\n- Direct values: `\"api_key_value\"`\n- System environment variables: `{:system, \"ENV_VAR_NAME\"}`\n- System environment integers: `{:system, :integer, \"ENV_VAR_NAME\"}`","ref":"HipcallSMS.Adapter.html#get_config_value/2"},{"type":"function","title":"Parameters - HipcallSMS.Adapter.get_config_value/2","doc":"- `key` - The configuration key to retrieve\n- `default` - Default value if the key is not found or is nil","ref":"HipcallSMS.Adapter.html#get_config_value/2-parameters"},{"type":"function","title":"Returns - HipcallSMS.Adapter.get_config_value/2","doc":"The configuration value or the default if not found.","ref":"HipcallSMS.Adapter.html#get_config_value/2-returns"},{"type":"function","title":"Examples - HipcallSMS.Adapter.get_config_value/2","doc":"# Direct configuration value\n    # config :hipcall_sms, api_key: \"secret123\"\n    iex> HipcallSMS.Adapter.get_config_value(:api_key, nil)\n    \"secret123\"\n\n    # System environment variable\n    # config :hipcall_sms, api_key: {:system, \"SMS_API_KEY\"}\n    # Environment: SMS_API_KEY=secret123\n    iex> HipcallSMS.Adapter.get_config_value(:api_key, nil)\n    \"secret123\"\n\n    # System environment integer\n    # config :hipcall_sms, timeout: {:system, :integer, \"SMS_TIMEOUT\"}\n    # Environment: SMS_TIMEOUT=5000\n    iex> HipcallSMS.Adapter.get_config_value(:timeout, 3000)\n    5000\n\n    # Default value when not configured\n    iex> HipcallSMS.Adapter.get_config_value(:missing_key, \"default_value\")\n    \"default_value\"\n\n    # Nil value returns default\n    # config :hipcall_sms, some_key: nil\n    iex> HipcallSMS.Adapter.get_config_value(:some_key, \"default\")\n    \"default\"","ref":"HipcallSMS.Adapter.html#get_config_value/2-examples"},{"type":"callback","title":"HipcallSMS.Adapter.get_config_value/2","doc":"Gets a configuration value with a default fallback.\n\nThis callback retrieves configuration values from the application environment,\nwith support for system environment variables and default values.","ref":"HipcallSMS.Adapter.html#c:get_config_value/2"},{"type":"callback","title":"Parameters - HipcallSMS.Adapter.get_config_value/2","doc":"- `key` - The configuration key to retrieve\n- `default` - Default value if the key is not found","ref":"HipcallSMS.Adapter.html#c:get_config_value/2-parameters"},{"type":"callback","title":"Returns - HipcallSMS.Adapter.get_config_value/2","doc":"The configuration value or the default if not found.","ref":"HipcallSMS.Adapter.html#c:get_config_value/2-returns"},{"type":"type","title":"HipcallSMS.Adapter.sms/0","doc":"","ref":"HipcallSMS.Adapter.html#t:sms/0"},{"type":"type","title":"HipcallSMS.Adapter.t/0","doc":"","ref":"HipcallSMS.Adapter.html#t:t/0"},{"type":"callback","title":"HipcallSMS.Adapter.validate_config/1","doc":"Validates the adapter configuration.\n\nThis callback validates that all required configuration keys are present\nand have valid values.","ref":"HipcallSMS.Adapter.html#c:validate_config/1"},{"type":"callback","title":"Parameters - HipcallSMS.Adapter.validate_config/1","doc":"- `config` - Configuration keyword list to validate","ref":"HipcallSMS.Adapter.html#c:validate_config/1-parameters"},{"type":"callback","title":"Returns - HipcallSMS.Adapter.validate_config/1","doc":"- `:ok` - Configuration is valid\n- Raises `ArgumentError` - If required configuration is missing","ref":"HipcallSMS.Adapter.html#c:validate_config/1-returns"},{"type":"function","title":"HipcallSMS.Adapter.validate_config/2","doc":"Validates that all required configuration keys are present.\n\nThis function checks that all keys in the `required_config` list are present\nin the provided configuration and have non-nil, non-empty values.","ref":"HipcallSMS.Adapter.html#validate_config/2"},{"type":"function","title":"Parameters - HipcallSMS.Adapter.validate_config/2","doc":"- `required_config` - List of required configuration keys (atoms)\n- `config` - Configuration keyword list to validate","ref":"HipcallSMS.Adapter.html#validate_config/2-parameters"},{"type":"function","title":"Returns - HipcallSMS.Adapter.validate_config/2","doc":"- `:ok` - All required configuration is present\n- Raises `ArgumentError` - If any required configuration is missing","ref":"HipcallSMS.Adapter.html#validate_config/2-returns"},{"type":"function","title":"Examples - HipcallSMS.Adapter.validate_config/2","doc":"# Valid configuration\n    iex> HipcallSMS.Adapter.validate_config([:api_key], [api_key: \"secret123\"])\n    :ok\n\n    # Missing required key\n    iex> HipcallSMS.Adapter.validate_config([:api_key, :secret], [api_key: \"secret123\"])\n    ** (ArgumentError) Missing required configuration: [:secret], got: [api_key: \"secret123\"]\n\n    # Empty value treated as missing\n    iex> HipcallSMS.Adapter.validate_config([:api_key], [api_key: \"\"])\n    ** (ArgumentError) Missing required configuration: [:api_key], got: [api_key: \"\"]","ref":"HipcallSMS.Adapter.html#validate_config/2-examples"},{"type":"callback","title":"HipcallSMS.Adapter.validate_dependency/0","doc":"Validates that required dependencies are available.\n\nThis callback checks that all required dependencies are loaded and available\nat runtime.","ref":"HipcallSMS.Adapter.html#c:validate_dependency/0"},{"type":"callback","title":"Returns - HipcallSMS.Adapter.validate_dependency/0","doc":"- `:ok` - All dependencies are available\n- `{:error, missing_deps}` - List of missing dependencies","ref":"HipcallSMS.Adapter.html#c:validate_dependency/0-returns"},{"type":"function","title":"HipcallSMS.Adapter.validate_dependency/1","doc":"Validates that all required dependencies are available.\n\nThis function checks that all modules in the `required_deps` list are loaded\nand available at runtime. Dependencies can be specified as module names or\nas `{library_name, module}` tuples.","ref":"HipcallSMS.Adapter.html#validate_dependency/1"},{"type":"function","title":"Parameters - HipcallSMS.Adapter.validate_dependency/1","doc":"- `required_deps` - List of required dependencies","ref":"HipcallSMS.Adapter.html#validate_dependency/1-parameters"},{"type":"function","title":"Returns - HipcallSMS.Adapter.validate_dependency/1","doc":"- `:ok` - All dependencies are available\n- `{:error, missing_deps}` - List of missing dependencies","ref":"HipcallSMS.Adapter.html#validate_dependency/1-returns"},{"type":"function","title":"Examples - HipcallSMS.Adapter.validate_dependency/1","doc":"# All dependencies available\n    iex> HipcallSMS.Adapter.validate_dependency([Jason, Finch])\n    :ok\n\n    # Missing dependency\n    iex> HipcallSMS.Adapter.validate_dependency([NonExistentModule])\n    {:error, [NonExistentModule]}\n\n    # Mixed dependency specification\n    iex> HipcallSMS.Adapter.validate_dependency([Jason, {:finch, Finch}])\n    :ok","ref":"HipcallSMS.Adapter.html#validate_dependency/1-examples"},{"type":"module","title":"HipcallSMS.Adapters.Iletimerkezi","doc":"An adapter for Iletimerkezi SMS API.\n\nThis adapter provides SMS delivery through Iletimerkezi's REST API, which is a\npopular SMS service provider in Turkey. It supports scheduled messaging and\nIYS (İzinli Yollama Sistemi) compliance for Turkish regulations.\n\nFor reference: [Iletimerkezi API docs](https://www.toplusmsapi.com/sms/gonder/json)","ref":"HipcallSMS.Adapters.Iletimerkezi.html"},{"type":"module","title":"Configuration - HipcallSMS.Adapters.Iletimerkezi","doc":"The Iletimerkezi adapter requires the following configuration:\n\n- `:key` - Your Iletimerkezi API key\n- `:hash` - Your Iletimerkezi API hash","ref":"HipcallSMS.Adapters.Iletimerkezi.html#module-configuration"},{"type":"module","title":"Configuration Examples - HipcallSMS.Adapters.Iletimerkezi","doc":"# In config/config.exs\n    config :hipcall_sms,\n      adapter: HipcallSMS.Adapters.Iletimerkezi,\n      iletimerkezi_key: {:system, \"ILETIMERKEZI_KEY\"},\n      iletimerkezi_hash: {:system, \"ILETIMERKEZI_HASH\"}\n\n    # Runtime configuration override\n    config = [\n      adapter: HipcallSMS.Adapters.Iletimerkezi,\n      key: \"your_api_key\",\n      hash: \"your_api_hash\"\n    ]","ref":"HipcallSMS.Adapters.Iletimerkezi.html#module-configuration-examples"},{"type":"module","title":"Provider Options - HipcallSMS.Adapters.Iletimerkezi","doc":"The Iletimerkezi adapter supports the following provider-specific options via `provider_options`:\n\n- `:send_date_time` - Schedule message for future delivery (array format)\n- `:iys` - IYS compliance setting (default: \"1\")\n- `:iys_list` - IYS list type (default: \"BIREYSEL\")","ref":"HipcallSMS.Adapters.Iletimerkezi.html#module-provider-options"},{"type":"module","title":"Examples - HipcallSMS.Adapters.Iletimerkezi","doc":"# Basic SMS\n    sms = SMS.new(from: \"SENDER\", to: \"+905551234567\", text: \"Merhaba!\")\n    {:ok, response} = HipcallSMS.deliver(sms)\n\n    # Scheduled SMS\n    sms =\n      SMS.new(from: \"SENDER\", to: \"+905551234567\", text: \"Hatırlatma!\")\n      |> SMS.put_provider_option(:send_date_time, [\"2024\", \"12\", \"25\", \"10\", \"30\"])\n\n    # SMS with custom IYS settings\n    sms =\n      SMS.new(from: \"SENDER\", to: \"+905551234567\", text: \"Bilgilendirme\")\n      |> SMS.put_provider_option(:iys, \"1\")\n      |> SMS.put_provider_option(:iys_list, \"TACIR\")","ref":"HipcallSMS.Adapters.Iletimerkezi.html#module-examples"},{"type":"function","title":"HipcallSMS.Adapters.Iletimerkezi.deliver/2","doc":"Delivers an SMS through Iletimerkezi's REST API.\n\nThis function sends an SMS message using Iletimerkezi's JSON API. It handles\nauthentication, request formatting, and response parsing with IYS compliance.","ref":"HipcallSMS.Adapters.Iletimerkezi.html#deliver/2"},{"type":"function","title":"Parameters - HipcallSMS.Adapters.Iletimerkezi.deliver/2","doc":"- `sms` - The SMS struct containing message details\n- `config` - Configuration keyword list (optional, defaults to application config)","ref":"HipcallSMS.Adapters.Iletimerkezi.html#deliver/2-parameters"},{"type":"function","title":"Returns - HipcallSMS.Adapters.Iletimerkezi.deliver/2","doc":"- `{:ok, response}` - Success with Iletimerkezi API response\n- `{:error, reason}` - Failure with error details including HTTP status and body","ref":"HipcallSMS.Adapters.Iletimerkezi.html#deliver/2-returns"},{"type":"function","title":"Response Format - HipcallSMS.Adapters.Iletimerkezi.deliver/2","doc":"Success responses contain the raw Iletimerkezi API response:\n\n    {:ok, %{\n      \"response\" => %{\n        \"status\" => %{\n          \"code\" => \"200\",\n          \"message\" => \"OK\"\n        },\n        \"order\" => %{\n          \"id\" => \"order_id\"\n        }\n      }\n    }}","ref":"HipcallSMS.Adapters.Iletimerkezi.html#deliver/2-response-format"},{"type":"function","title":"Examples - HipcallSMS.Adapters.Iletimerkezi.deliver/2","doc":"# Basic delivery\n    sms = SMS.new(from: \"SENDER\", to: \"+905551234567\", text: \"Merhaba!\")\n    {:ok, response} = deliver(sms)\n\n    # Delivery with custom config\n    config = [key: \"custom_key\", hash: \"custom_hash\"]\n    {:ok, response} = deliver(sms, config)","ref":"HipcallSMS.Adapters.Iletimerkezi.html#deliver/2-examples"},{"type":"function","title":"HipcallSMS.Adapters.Iletimerkezi.get_balance/1","doc":"Gets the account balance from Iletimerkezi's REST API.\n\nThis function retrieves the current account balance using Iletimerkezi's Balance API.\nIt handles authentication and response parsing.","ref":"HipcallSMS.Adapters.Iletimerkezi.html#get_balance/1"},{"type":"function","title":"Parameters - HipcallSMS.Adapters.Iletimerkezi.get_balance/1","doc":"- `config` - Configuration keyword list (optional, defaults to application config)","ref":"HipcallSMS.Adapters.Iletimerkezi.html#get_balance/1-parameters"},{"type":"function","title":"Returns - HipcallSMS.Adapters.Iletimerkezi.get_balance/1","doc":"- `{:ok, balance_info}` - Success with balance information\n- `{:error, reason}` - Failure with error details including HTTP status and body","ref":"HipcallSMS.Adapters.Iletimerkezi.html#get_balance/1-returns"},{"type":"function","title":"Response Format - HipcallSMS.Adapters.Iletimerkezi.get_balance/1","doc":"Success responses contain normalized balance information:\n\n    %{\n      balance: \"300.00\",           # Current account balance (TL)\n      sms_balance: \"18343\",        # SMS credit balance\n      currency: \"TRY\",             # Currency (Turkish Lira)\n      provider: \"iletimerkezi\",    # Provider identifier\n      provider_response: %{}       # Full Iletimerkezi API response\n    }","ref":"HipcallSMS.Adapters.Iletimerkezi.html#get_balance/1-response-format"},{"type":"function","title":"Examples - HipcallSMS.Adapters.Iletimerkezi.get_balance/1","doc":"# Get balance with application config\n    {:ok, balance} = get_balance()\n\n    # Get balance with custom config\n    config = [key: \"custom_key\", hash: \"custom_hash\"]\n    {:ok, balance} = get_balance(config)","ref":"HipcallSMS.Adapters.Iletimerkezi.html#get_balance/1-examples"},{"type":"function","title":"HipcallSMS.Adapters.Iletimerkezi.get_config_value/2","doc":"Callback implementation for  HipcallSMS.Adapter.get_config_value/2 .","ref":"HipcallSMS.Adapters.Iletimerkezi.html#get_config_value/2"},{"type":"function","title":"HipcallSMS.Adapters.Iletimerkezi.validate_config/1","doc":"Callback implementation for  HipcallSMS.Adapter.validate_config/1 .","ref":"HipcallSMS.Adapters.Iletimerkezi.html#validate_config/1"},{"type":"function","title":"HipcallSMS.Adapters.Iletimerkezi.validate_dependency/0","doc":"Callback implementation for  HipcallSMS.Adapter.validate_dependency/0 .","ref":"HipcallSMS.Adapters.Iletimerkezi.html#validate_dependency/0"},{"type":"module","title":"HipcallSMS.Adapters.Telnyx","doc":"An adapter for Telnyx SMS API.\n\nThis adapter provides SMS delivery through Telnyx's REST API. It supports messaging\nprofiles, webhooks, auto-detection, and media attachments for MMS.\n\nFor reference: [Telnyx API docs](https://developers.telnyx.com/api/messaging/send-message)","ref":"HipcallSMS.Adapters.Telnyx.html"},{"type":"module","title":"Configuration - HipcallSMS.Adapters.Telnyx","doc":"The Telnyx adapter requires the following configuration:\n\n- `:api_key` - Your Telnyx API key","ref":"HipcallSMS.Adapters.Telnyx.html#module-configuration"},{"type":"module","title":"Configuration Examples - HipcallSMS.Adapters.Telnyx","doc":"# In config/config.exs\n    config :hipcall_sms,\n      adapter: HipcallSMS.Adapters.Telnyx,\n      telnyx_api_key: {:system, \"TELNYX_API_KEY\"}\n\n    # Runtime configuration override\n    config = [\n      adapter: HipcallSMS.Adapters.Telnyx,\n      api_key: \"your_api_key\"\n    ]","ref":"HipcallSMS.Adapters.Telnyx.html#module-configuration-examples"},{"type":"module","title":"Provider Options - HipcallSMS.Adapters.Telnyx","doc":"The Telnyx adapter supports the following provider-specific options via `provider_options`:\n\n- `:messaging_profile_id` - Messaging profile ID to use for sending\n- `:webhook_url` - URL for delivery status webhooks\n- `:webhook_failover_url` - Failover URL for webhooks\n- `:use_profile_webhooks` - Whether to use messaging profile webhooks (default: true)\n- `:type` - Message type, \"SMS\" or \"MMS\" (default: \"SMS\")\n- `:auto_detect` - Enable auto-detection of message type\n- `:media_urls` - Array of media URLs for MMS","ref":"HipcallSMS.Adapters.Telnyx.html#module-provider-options"},{"type":"module","title":"Examples - HipcallSMS.Adapters.Telnyx","doc":"# Basic SMS\n    sms = SMS.new(from: \"+15551234567\", to: \"+15555555555\", text: \"Hello!\")\n    {:ok, response} = HipcallSMS.deliver(sms)\n\n    # SMS with messaging profile\n    sms =\n      SMS.new(from: \"+15551234567\", to: \"+15555555555\", text: \"Hello!\")\n      |> SMS.put_provider_option(:messaging_profile_id, \"profile_123\")\n\n    # SMS with webhook\n    sms =\n      SMS.new(from: \"+15551234567\", to: \"+15555555555\", text: \"Hello!\")\n      |> SMS.put_provider_option(:webhook_url, \"https://example.com/webhook\")\n\n    # MMS with media\n    sms =\n      SMS.new(from: \"+15551234567\", to: \"+15555555555\", text: \"Check this out!\")\n      |> SMS.put_provider_option(:type, \"MMS\")\n      |> SMS.put_provider_option(:media_urls, [\"https://example.com/image.jpg\"])","ref":"HipcallSMS.Adapters.Telnyx.html#module-examples"},{"type":"function","title":"HipcallSMS.Adapters.Telnyx.deliver/2","doc":"Delivers an SMS through Telnyx's REST API.\n\nThis function sends an SMS message using Telnyx's Messages API. It handles\nauthentication, request formatting, and response parsing.","ref":"HipcallSMS.Adapters.Telnyx.html#deliver/2"},{"type":"function","title":"Parameters - HipcallSMS.Adapters.Telnyx.deliver/2","doc":"- `sms` - The SMS struct containing message details\n- `config` - Configuration keyword list (optional, defaults to application config)","ref":"HipcallSMS.Adapters.Telnyx.html#deliver/2-parameters"},{"type":"function","title":"Returns - HipcallSMS.Adapters.Telnyx.deliver/2","doc":"- `{:ok, response}` - Success with normalized response containing message ID and status\n- `{:error, reason}` - Failure with error details including HTTP status and body","ref":"HipcallSMS.Adapters.Telnyx.html#deliver/2-returns"},{"type":"function","title":"Response Format - HipcallSMS.Adapters.Telnyx.deliver/2","doc":"Success responses are normalized to:\n\n    %{\n      id: \"msg_123\",           # Telnyx message ID\n      status: \"queued\",        # Message status\n      provider: \"telnyx\",      # Provider identifier\n      provider_response: %{}   # Full Telnyx API response\n    }","ref":"HipcallSMS.Adapters.Telnyx.html#deliver/2-response-format"},{"type":"function","title":"Examples - HipcallSMS.Adapters.Telnyx.deliver/2","doc":"# Basic delivery\n    sms = SMS.new(from: \"+15551234567\", to: \"+15555555555\", text: \"Hello!\")\n    {:ok, response} = deliver(sms)\n    # => {:ok, %{id: \"msg_123\", status: \"queued\", provider: \"telnyx\"}}\n\n    # Delivery with custom config\n    config = [api_key: \"custom_api_key\"]\n    {:ok, response} = deliver(sms, config)","ref":"HipcallSMS.Adapters.Telnyx.html#deliver/2-examples"},{"type":"function","title":"HipcallSMS.Adapters.Telnyx.get_balance/1","doc":"Gets the account balance from Telnyx's REST API.\n\nThis function retrieves the current account balance using Telnyx's Balance API.\nIt handles authentication and response parsing.","ref":"HipcallSMS.Adapters.Telnyx.html#get_balance/1"},{"type":"function","title":"Parameters - HipcallSMS.Adapters.Telnyx.get_balance/1","doc":"- `config` - Configuration keyword list (optional, defaults to application config)","ref":"HipcallSMS.Adapters.Telnyx.html#get_balance/1-parameters"},{"type":"function","title":"Returns - HipcallSMS.Adapters.Telnyx.get_balance/1","doc":"- `{:ok, balance_info}` - Success with balance information\n- `{:error, reason}` - Failure with error details including HTTP status and body","ref":"HipcallSMS.Adapters.Telnyx.html#get_balance/1-returns"},{"type":"function","title":"Response Format - HipcallSMS.Adapters.Telnyx.get_balance/1","doc":"Success responses contain normalized balance information:\n\n    %{\n      balance: \"300.00\",           # Current account balance\n      currency: \"USD\",             # Currency code\n      credit_limit: \"100.00\",      # Credit limit\n      available_credit: \"400.00\",  # Available credit (balance + credit limit)\n      pending: \"10.00\",            # Pending amount\n      provider: \"telnyx\",          # Provider identifier\n      provider_response: %{}       # Full Telnyx API response\n    }","ref":"HipcallSMS.Adapters.Telnyx.html#get_balance/1-response-format"},{"type":"function","title":"Examples - HipcallSMS.Adapters.Telnyx.get_balance/1","doc":"# Get balance with application config\n    {:ok, balance} = get_balance()\n\n    # Get balance with custom config\n    config = [api_key: \"custom_api_key\"]\n    {:ok, balance} = get_balance(config)","ref":"HipcallSMS.Adapters.Telnyx.html#get_balance/1-examples"},{"type":"function","title":"HipcallSMS.Adapters.Telnyx.get_config_value/2","doc":"Callback implementation for  HipcallSMS.Adapter.get_config_value/2 .","ref":"HipcallSMS.Adapters.Telnyx.html#get_config_value/2"},{"type":"function","title":"HipcallSMS.Adapters.Telnyx.validate_config/1","doc":"Callback implementation for  HipcallSMS.Adapter.validate_config/1 .","ref":"HipcallSMS.Adapters.Telnyx.html#validate_config/1"},{"type":"function","title":"HipcallSMS.Adapters.Telnyx.validate_dependency/0","doc":"Callback implementation for  HipcallSMS.Adapter.validate_dependency/0 .","ref":"HipcallSMS.Adapters.Telnyx.html#validate_dependency/0"},{"type":"module","title":"HipcallSMS.Adapters.Test","doc":"An adapter that sends SMS as messages to the current process.\n\nThis adapter is designed for testing purposes and does not actually send SMS messages\nthrough any external service. Instead, it sends the SMS struct as a message to the\ncurrent process, allowing you to assert that SMS messages were sent in your tests.\n\nThis is meant to be used during tests and works with the assertions found in\nthe [HipcallSMS.TestAssertions](HipcallSMS.TestAssertions.html) module.","ref":"HipcallSMS.Adapters.Test.html"},{"type":"module","title":"Configuration - HipcallSMS.Adapters.Test","doc":"The Test adapter does not require any configuration keys, but you can optionally\nconfigure a shared test process to receive all SMS messages.","ref":"HipcallSMS.Adapters.Test.html#module-configuration"},{"type":"module","title":"Configuration Examples - HipcallSMS.Adapters.Test","doc":"# In config/test.exs\n    config :hipcall_sms,\n      adapter: HipcallSMS.Adapters.Test\n\n    # With shared test process\n    config :hipcall_sms,\n      adapter: HipcallSMS.Adapters.Test,\n      shared_test_process: self()","ref":"HipcallSMS.Adapters.Test.html#module-configuration-examples"},{"type":"module","title":"Usage in Tests - HipcallSMS.Adapters.Test","doc":"# Basic test\n    test \"sends welcome SMS\" do\n      sms = SMS.new(from: \"+15551234567\", to: \"+15555555555\", text: \"Welcome!\")\n      {:ok, _response} = HipcallSMS.deliver(sms)\n\n      assert_received {:sms, %SMS{text: \"Welcome!\"}}\n    end\n\n    # With pattern matching\n    test \"sends SMS with correct details\" do\n      sms = SMS.new(from: \"+15551234567\", to: \"+15555555555\", text: \"Hello!\")\n      {:ok, _response} = HipcallSMS.deliver(sms)\n\n      assert_received {:sms, %SMS{\n        from: \"+15551234567\",\n        to: \"+15555555555\",\n        text: \"Hello!\"\n      }}\n    end","ref":"HipcallSMS.Adapters.Test.html#module-usage-in-tests"},{"type":"module","title":"Process Selection - HipcallSMS.Adapters.Test","doc":"The adapter sends messages to processes in the following order of preference:\n\n1. The process configured in `:shared_test_process` application environment\n2. The current process (`self()`)\n3. Any processes in the `$callers` process dictionary (for GenServer calls)","ref":"HipcallSMS.Adapters.Test.html#module-process-selection"},{"type":"function","title":"HipcallSMS.Adapters.Test.deliver/2","doc":"Delivers an SMS by sending it as a message to test processes.\n\nThis function does not actually send an SMS through any external service.\nInstead, it sends the SMS struct as a `{:sms, sms}` message to the appropriate\ntest processes, allowing you to assert that the SMS was sent in your tests.","ref":"HipcallSMS.Adapters.Test.html#deliver/2"},{"type":"function","title":"Parameters - HipcallSMS.Adapters.Test.deliver/2","doc":"- `sms` - The SMS struct containing message details\n- `config` - Configuration (ignored for the test adapter)","ref":"HipcallSMS.Adapters.Test.html#deliver/2-parameters"},{"type":"function","title":"Returns - HipcallSMS.Adapters.Test.deliver/2","doc":"Always returns `{:ok, %{}}` to simulate successful delivery.","ref":"HipcallSMS.Adapters.Test.html#deliver/2-returns"},{"type":"function","title":"Examples - HipcallSMS.Adapters.Test.deliver/2","doc":"# In a test\n    sms = SMS.new(from: \"+15551234567\", to: \"+15555555555\", text: \"Test message\")\n    {:ok, response} = deliver(sms, [])\n    # => {:ok, %{}}\n\n    # Then assert the message was received\n    assert_received {:sms, %SMS{text: \"Test message\"}}","ref":"HipcallSMS.Adapters.Test.html#deliver/2-examples"},{"type":"function","title":"HipcallSMS.Adapters.Test.get_balance/1","doc":"Gets a mock account balance for testing purposes.\n\nThis function returns a mock balance response that can be used in tests\nto simulate balance checking functionality.","ref":"HipcallSMS.Adapters.Test.html#get_balance/1"},{"type":"function","title":"Parameters - HipcallSMS.Adapters.Test.get_balance/1","doc":"- `config` - Configuration (ignored for the test adapter)","ref":"HipcallSMS.Adapters.Test.html#get_balance/1-parameters"},{"type":"function","title":"Returns - HipcallSMS.Adapters.Test.get_balance/1","doc":"Always returns a mock balance response.","ref":"HipcallSMS.Adapters.Test.html#get_balance/1-returns"},{"type":"function","title":"Examples - HipcallSMS.Adapters.Test.get_balance/1","doc":"# In a test\n    {:ok, balance} = get_balance([])\n    # => {:ok, %{balance: \"100.00\", currency: \"USD\", provider: \"test\"}}","ref":"HipcallSMS.Adapters.Test.html#get_balance/1-examples"},{"type":"function","title":"HipcallSMS.Adapters.Test.get_config_value/2","doc":"Callback implementation for  HipcallSMS.Adapter.get_config_value/2 .","ref":"HipcallSMS.Adapters.Test.html#get_config_value/2"},{"type":"function","title":"HipcallSMS.Adapters.Test.validate_config/1","doc":"Callback implementation for  HipcallSMS.Adapter.validate_config/1 .","ref":"HipcallSMS.Adapters.Test.html#validate_config/1"},{"type":"function","title":"HipcallSMS.Adapters.Test.validate_dependency/0","doc":"Callback implementation for  HipcallSMS.Adapter.validate_dependency/0 .","ref":"HipcallSMS.Adapters.Test.html#validate_dependency/0"},{"type":"module","title":"HipcallSMS.Adapters.Twilio","doc":"An adapter for Twilio SMS API.\n\nThis adapter provides SMS delivery through Twilio's REST API. It supports all major\nTwilio SMS features including messaging services, status callbacks, scheduling,\nand media attachments.\n\nFor reference: [Twilio API docs](https://www.twilio.com/docs/sms/api/message-resource#create-a-message-resource)","ref":"HipcallSMS.Adapters.Twilio.html"},{"type":"module","title":"Configuration - HipcallSMS.Adapters.Twilio","doc":"The Twilio adapter requires the following configuration:\n\n- `:account_sid` - Your Twilio Account SID\n- `:auth_token` - Your Twilio Auth Token","ref":"HipcallSMS.Adapters.Twilio.html#module-configuration"},{"type":"module","title":"Configuration Examples - HipcallSMS.Adapters.Twilio","doc":"# In config/config.exs\n    config :hipcall_sms,\n      adapter: HipcallSMS.Adapters.Twilio,\n      twilio_account_sid: {:system, \"TWILIO_ACCOUNT_SID\"},\n      twilio_auth_token: {:system, \"TWILIO_AUTH_TOKEN\"}\n\n    # Runtime configuration override\n    config = [\n      adapter: HipcallSMS.Adapters.Twilio,\n      account_sid: \"ACxxxxx\",\n      auth_token: \"your_auth_token\"\n    ]","ref":"HipcallSMS.Adapters.Twilio.html#module-configuration-examples"},{"type":"module","title":"Provider Options - HipcallSMS.Adapters.Twilio","doc":"The Twilio adapter supports the following provider-specific options via `provider_options`:\n\n- `:messaging_service_sid` - Use a Twilio Messaging Service\n- `:status_callback` - URL for delivery status webhooks\n- `:media_url` - URL for MMS media attachments\n- `:max_price` - Maximum price per message\n- `:validity_period` - Message validity period in seconds\n- `:send_at` - Schedule message for future delivery\n- `:smart_encoded` - Enable smart encoding\n- `:shorten_urls` - Enable URL shortening","ref":"HipcallSMS.Adapters.Twilio.html#module-provider-options"},{"type":"module","title":"Examples - HipcallSMS.Adapters.Twilio","doc":"# Basic SMS\n    sms = SMS.new(from: \"+15551234567\", to: \"+15555555555\", text: \"Hello!\")\n    {:ok, response} = HipcallSMS.deliver(sms)\n\n    # SMS with messaging service\n    sms =\n      SMS.new(to: \"+15555555555\", text: \"Hello!\")\n      |> SMS.put_provider_option(:messaging_service_sid, \"MGxxxxx\")\n\n    # SMS with status callback\n    sms =\n      SMS.new(from: \"+15551234567\", to: \"+15555555555\", text: \"Hello!\")\n      |> SMS.put_provider_option(:status_callback, \"https://example.com/webhook\")\n\n    # Scheduled SMS\n    send_at = DateTime.utc_now() |> DateTime.add(3600, :second) |> DateTime.to_iso8601()\n    sms =\n      SMS.new(from: \"+15551234567\", to: \"+15555555555\", text: \"Reminder!\")\n      |> SMS.put_provider_option(:send_at, send_at)","ref":"HipcallSMS.Adapters.Twilio.html#module-examples"},{"type":"function","title":"HipcallSMS.Adapters.Twilio.deliver/2","doc":"Delivers an SMS through Twilio's REST API.\n\nThis function sends an SMS message using Twilio's Messages API. It handles\nauthentication, request formatting, and response parsing.","ref":"HipcallSMS.Adapters.Twilio.html#deliver/2"},{"type":"function","title":"Parameters - HipcallSMS.Adapters.Twilio.deliver/2","doc":"- `sms` - The SMS struct containing message details\n- `config` - Configuration keyword list (optional, defaults to application config)","ref":"HipcallSMS.Adapters.Twilio.html#deliver/2-parameters"},{"type":"function","title":"Returns - HipcallSMS.Adapters.Twilio.deliver/2","doc":"- `{:ok, response}` - Success with normalized response containing message ID and status\n- `{:error, reason}` - Failure with error details including HTTP status and body","ref":"HipcallSMS.Adapters.Twilio.html#deliver/2-returns"},{"type":"function","title":"Response Format - HipcallSMS.Adapters.Twilio.deliver/2","doc":"Success responses are normalized to:\n\n    %{\n      id: \"SMxxxxx\",           # Twilio message SID\n      status: \"queued\",        # Message status\n      provider: \"twilio\",      # Provider identifier\n      provider_response: %{}   # Full Twilio API response\n    }","ref":"HipcallSMS.Adapters.Twilio.html#deliver/2-response-format"},{"type":"function","title":"Examples - HipcallSMS.Adapters.Twilio.deliver/2","doc":"# Basic delivery\n    sms = SMS.new(from: \"+15551234567\", to: \"+15555555555\", text: \"Hello!\")\n    {:ok, response} = deliver(sms)\n    # => {:ok, %{id: \"SMxxxxx\", status: \"queued\", provider: \"twilio\"}}\n\n    # Delivery with custom config\n    config = [account_sid: \"ACxxxxx\", auth_token: \"custom_token\"]\n    {:ok, response} = deliver(sms, config)","ref":"HipcallSMS.Adapters.Twilio.html#deliver/2-examples"},{"type":"function","title":"HipcallSMS.Adapters.Twilio.get_balance/1","doc":"Gets the account balance from Twilio.\n\nNote: Twilio does not provide a simple balance endpoint like other providers.\nThis function returns an error indicating that balance checking is not supported\nfor Twilio through this adapter.\n\nFor Twilio balance information, you would need to use their Account API\nor check your Twilio Console.","ref":"HipcallSMS.Adapters.Twilio.html#get_balance/1"},{"type":"function","title":"Parameters - HipcallSMS.Adapters.Twilio.get_balance/1","doc":"- `config` - Configuration keyword list (ignored)","ref":"HipcallSMS.Adapters.Twilio.html#get_balance/1-parameters"},{"type":"function","title":"Returns - HipcallSMS.Adapters.Twilio.get_balance/1","doc":"- `{:error, reason}` - Always returns an error as this feature is not supported","ref":"HipcallSMS.Adapters.Twilio.html#get_balance/1-returns"},{"type":"function","title":"HipcallSMS.Adapters.Twilio.get_config_value/2","doc":"Callback implementation for  HipcallSMS.Adapter.get_config_value/2 .","ref":"HipcallSMS.Adapters.Twilio.html#get_config_value/2"},{"type":"function","title":"HipcallSMS.Adapters.Twilio.validate_config/1","doc":"Callback implementation for  HipcallSMS.Adapter.validate_config/1 .","ref":"HipcallSMS.Adapters.Twilio.html#validate_config/1"},{"type":"function","title":"HipcallSMS.Adapters.Twilio.validate_dependency/0","doc":"Callback implementation for  HipcallSMS.Adapter.validate_dependency/0 .","ref":"HipcallSMS.Adapters.Twilio.html#validate_dependency/0"},{"type":"behaviour","title":"HipcallSMS.HTTPClient","doc":"Behavior for HTTP client operations.\n\nThis behavior defines the contract for making HTTP requests, allowing for\neasy mocking in tests while using Finch in production.","ref":"HipcallSMS.HTTPClient.html"},{"type":"callback","title":"HipcallSMS.HTTPClient.request/5","doc":"Makes an HTTP request.","ref":"HipcallSMS.HTTPClient.html#c:request/5"},{"type":"callback","title":"Parameters - HipcallSMS.HTTPClient.request/5","doc":"- `method` - HTTP method (:get, :post, :put, :delete, etc.)\n- `url` - Request URL\n- `headers` - List of header tuples\n- `body` - Request body (optional)\n- `opts` - Additional options (optional)","ref":"HipcallSMS.HTTPClient.html#c:request/5-parameters"},{"type":"callback","title":"Returns - HipcallSMS.HTTPClient.request/5","doc":"- `{:ok, %{status: integer(), body: binary(), headers: list()}}` - Success response\n- `{:error, reason}` - Error response","ref":"HipcallSMS.HTTPClient.html#c:request/5-returns"},{"type":"module","title":"HipcallSMS.HTTPClient.FinchClient","doc":"Finch-based implementation of the HTTPClient behavior.\n\nThis module provides the production HTTP client implementation using Finch.","ref":"HipcallSMS.HTTPClient.FinchClient.html"},{"type":"module","title":"HipcallSMS.SMS","doc":"Define a SMS.\n\nThis module defines a `HipcallSMS.SMS` struct and the main functions for composing an SMS.  As it is the contract for\nthe public APIs of HipcallSMS it is a good idea to make use of these functions rather than build the struct yourself.","ref":"HipcallSMS.SMS.html"},{"type":"module","title":"SMS fields - HipcallSMS.SMS","doc":"* `id` - the unique identifier of the SMS, example: `\"40385f64-5717-4562-b3fc-2c963f66afa6\"`\n* `direction` - the direction of the SMS (`:outbound` or `:inbound`), example: `:outbound`\n* `from` - the sender of the SMS, example: `\"+15551234567\"`\n* `to` - the recipient of the SMS, example: `\"+15555555555\"`\n* `text` - the content of the SMS in plaintext, example: `\"Hello\"`","ref":"HipcallSMS.SMS.html#module-sms-fields"},{"type":"module","title":"Provider options - HipcallSMS.SMS","doc":"This key allow users to make use of provider-specific functionality by passing along addition parameters.\n\n* `provider_options` - a map of values that are specific to adapter provider, example: `%{async: true}`","ref":"HipcallSMS.SMS.html#module-provider-options"},{"type":"module","title":"Examples - HipcallSMS.SMS","doc":"sms =\n      new()\n      |> from(\"+15551234567\")\n      |> to(\"+15555555555\")\n      |> text(\"Welcome to the Hipcall\")\n\nThe composable nature makes it very easy to continue expanding upon a given SMS.\n\n    sms =\n      sms\n      |> from(\"+15551234567\")\n      |> to(\"+15555555555\")\n      |> text(\"Welcome to the Hipcall\")\n\nYou can also directly pass arguments to the `new/1` function.\n\n    sms = new(from: \"+15551234567\", to: \"+15555555555\", text: \"Welcome to the Hipcall!\")","ref":"HipcallSMS.SMS.html#module-examples"},{"type":"type","title":"HipcallSMS.SMS.direction/0","doc":"","ref":"HipcallSMS.SMS.html#t:direction/0"},{"type":"type","title":"HipcallSMS.SMS.from/0","doc":"","ref":"HipcallSMS.SMS.html#t:from/0"},{"type":"function","title":"HipcallSMS.SMS.from/2","doc":"Sets the sender of the SMS.\n\nThis function sets the `from` field of the SMS struct to the specified phone number.\nThe phone number should be in E.164 format for best compatibility across providers.","ref":"HipcallSMS.SMS.html#from/2"},{"type":"function","title":"Parameters - HipcallSMS.SMS.from/2","doc":"- `sms` - The SMS struct to modify\n- `from` - The sender phone number (E.164 format recommended)","ref":"HipcallSMS.SMS.html#from/2-parameters"},{"type":"function","title":"Returns - HipcallSMS.SMS.from/2","doc":"The updated SMS struct with the `from` field set.","ref":"HipcallSMS.SMS.html#from/2-returns"},{"type":"function","title":"Examples - HipcallSMS.SMS.from/2","doc":"# Set sender with E.164 format\n    iex> HipcallSMS.SMS.new() |> HipcallSMS.SMS.from(\"+15551234567\")\n    %HipcallSMS.SMS{direction: :outbound, from: \"+15551234567\"}\n\n    # Set sender with international format\n    iex> HipcallSMS.SMS.new() |> HipcallSMS.SMS.from(\"+442071234567\")\n    %HipcallSMS.SMS{direction: :outbound, from: \"+442071234567\"}\n\n    # Chain with other functions\n    iex> HipcallSMS.SMS.new()\n    ...> |> HipcallSMS.SMS.from(\"+15551234567\")\n    ...> |> HipcallSMS.SMS.to(\"+15555555555\")\n    ...> |> HipcallSMS.SMS.text(\"Hello!\")\n    %HipcallSMS.SMS{\n      direction: :outbound,\n      from: \"+15551234567\",\n      to: \"+15555555555\",\n      text: \"Hello!\"\n    }","ref":"HipcallSMS.SMS.html#from/2-examples"},{"type":"type","title":"HipcallSMS.SMS.id/0","doc":"","ref":"HipcallSMS.SMS.html#t:id/0"},{"type":"function","title":"HipcallSMS.SMS.new/1","doc":"Creates a new SMS struct.\n\nThis function creates a new SMS struct with default values. You can optionally\npass a keyword list to set initial values for the struct fields.","ref":"HipcallSMS.SMS.html#new/1"},{"type":"function","title":"Parameters - HipcallSMS.SMS.new/1","doc":"- `attrs` - Optional keyword list of attributes to set on the SMS struct","ref":"HipcallSMS.SMS.html#new/1-parameters"},{"type":"function","title":"Returns - HipcallSMS.SMS.new/1","doc":"A new `HipcallSMS.SMS` struct with the specified attributes set.","ref":"HipcallSMS.SMS.html#new/1-returns"},{"type":"function","title":"Examples - HipcallSMS.SMS.new/1","doc":"# Create an empty SMS struct\n    iex> HipcallSMS.SMS.new()\n    %HipcallSMS.SMS{direction: :outbound}\n\n    # Create an SMS struct with initial values\n    iex> HipcallSMS.SMS.new(from: \"+15551234567\", to: \"+15555555555\", text: \"Hello\")\n    %HipcallSMS.SMS{\n      direction: :outbound,\n      from: \"+15551234567\",\n      to: \"+15555555555\",\n      text: \"Hello\"\n    }\n\n    # Create an SMS struct with all fields\n    iex> HipcallSMS.SMS.new(\n    ...>   id: \"msg_123\",\n    ...>   from: \"+15551234567\",\n    ...>   to: \"+15555555555\",\n    ...>   text: \"Hello World\",\n    ...>   provider_options: %{priority: \"high\"}\n    ...> )\n    %HipcallSMS.SMS{\n      id: \"msg_123\",\n      direction: :outbound,\n      from: \"+15551234567\",\n      to: \"+15555555555\",\n      text: \"Hello World\",\n      provider_options: %{priority: \"high\"}\n    }","ref":"HipcallSMS.SMS.html#new/1-examples"},{"type":"type","title":"HipcallSMS.SMS.provider_options/0","doc":"","ref":"HipcallSMS.SMS.html#t:provider_options/0"},{"type":"function","title":"HipcallSMS.SMS.provider_options/2","doc":"Sets provider-specific options for the SMS.\n\nThis function replaces the entire `provider_options` map with the provided options.\nProvider options allow you to use provider-specific features that are not part\nof the standard SMS fields.","ref":"HipcallSMS.SMS.html#provider_options/2"},{"type":"function","title":"Parameters - HipcallSMS.SMS.provider_options/2","doc":"- `sms` - The SMS struct to modify\n- `options` - A map of provider-specific options","ref":"HipcallSMS.SMS.html#provider_options/2-parameters"},{"type":"function","title":"Returns - HipcallSMS.SMS.provider_options/2","doc":"The updated SMS struct with the `provider_options` field set.","ref":"HipcallSMS.SMS.html#provider_options/2-returns"},{"type":"function","title":"Examples - HipcallSMS.SMS.provider_options/2","doc":"# Set Twilio-specific options\n    iex> HipcallSMS.SMS.new() |> HipcallSMS.SMS.provider_options(%{status_callback: \"https://example.com/webhook\"})\n    %HipcallSMS.SMS{direction: :outbound, provider_options: %{status_callback: \"https://example.com/webhook\"}}\n\n    # Set Telnyx-specific options\n    iex> HipcallSMS.SMS.new() |> HipcallSMS.SMS.provider_options(%{messaging_profile_id: \"profile_123\", webhook_url: \"https://example.com/webhook\"})\n    %HipcallSMS.SMS{direction: :outbound, provider_options: %{messaging_profile_id: \"profile_123\", webhook_url: \"https://example.com/webhook\"}}\n\n    # Set multiple options\n    iex> HipcallSMS.SMS.new() |> HipcallSMS.SMS.provider_options(%{\n    ...>   priority: \"high\",\n    ...>   delivery_receipt: true,\n    ...>   validity_period: 3600\n    ...> })\n    %HipcallSMS.SMS{\n      direction: :outbound,\n      provider_options: %{\n        priority: \"high\",\n        delivery_receipt: true,\n        validity_period: 3600\n      }\n    }","ref":"HipcallSMS.SMS.html#provider_options/2-examples"},{"type":"function","title":"HipcallSMS.SMS.put_provider_option/3","doc":"Puts a single provider-specific option for the SMS.\n\nThis function adds or updates a single key-value pair in the `provider_options` map\nwithout affecting other existing options. This is useful when you want to add\nprovider-specific options incrementally.","ref":"HipcallSMS.SMS.html#put_provider_option/3"},{"type":"function","title":"Parameters - HipcallSMS.SMS.put_provider_option/3","doc":"- `sms` - The SMS struct to modify\n- `key` - The option key (atom or string)\n- `value` - The option value","ref":"HipcallSMS.SMS.html#put_provider_option/3-parameters"},{"type":"function","title":"Returns - HipcallSMS.SMS.put_provider_option/3","doc":"The updated SMS struct with the new option added to `provider_options`.","ref":"HipcallSMS.SMS.html#put_provider_option/3-returns"},{"type":"function","title":"Examples - HipcallSMS.SMS.put_provider_option/3","doc":"# Add a single option\n    iex> HipcallSMS.SMS.new() |> HipcallSMS.SMS.put_provider_option(:async, true)\n    %HipcallSMS.SMS{direction: :outbound, provider_options: %{async: true}}\n\n    # Add multiple options incrementally\n    iex> HipcallSMS.SMS.new()\n    ...> |> HipcallSMS.SMS.put_provider_option(:priority, \"high\")\n    ...> |> HipcallSMS.SMS.put_provider_option(:delivery_receipt, true)\n    %HipcallSMS.SMS{\n      direction: :outbound,\n      provider_options: %{priority: \"high\", delivery_receipt: true}\n    }\n\n    # Add to existing options\n    iex> sms = HipcallSMS.SMS.new() |> HipcallSMS.SMS.provider_options(%{existing: \"value\"})\n    iex> sms |> HipcallSMS.SMS.put_provider_option(:new_option, \"new_value\")\n    %HipcallSMS.SMS{\n      direction: :outbound,\n      provider_options: %{existing: \"value\", new_option: \"new_value\"}\n    }\n\n    # Use with string keys\n    iex> HipcallSMS.SMS.new() |> HipcallSMS.SMS.put_provider_option(\"webhook_url\", \"https://example.com/webhook\")\n    %HipcallSMS.SMS{direction: :outbound, provider_options: %{\"webhook_url\" => \"https://example.com/webhook\"}}","ref":"HipcallSMS.SMS.html#put_provider_option/3-examples"},{"type":"type","title":"HipcallSMS.SMS.t/0","doc":"","ref":"HipcallSMS.SMS.html#t:t/0"},{"type":"type","title":"HipcallSMS.SMS.text/0","doc":"","ref":"HipcallSMS.SMS.html#t:text/0"},{"type":"function","title":"HipcallSMS.SMS.text/2","doc":"Sets the text content of the SMS.\n\nThis function sets the `text` field of the SMS struct to the specified message content.\nThe text should be plain text. Different providers have different limits for SMS length,\ntypically 160 characters for single SMS or up to 1600 characters for concatenated SMS.","ref":"HipcallSMS.SMS.html#text/2"},{"type":"function","title":"Parameters - HipcallSMS.SMS.text/2","doc":"- `sms` - The SMS struct to modify\n- `text` - The message content as plain text","ref":"HipcallSMS.SMS.html#text/2-parameters"},{"type":"function","title":"Returns - HipcallSMS.SMS.text/2","doc":"The updated SMS struct with the `text` field set.","ref":"HipcallSMS.SMS.html#text/2-returns"},{"type":"function","title":"Examples - HipcallSMS.SMS.text/2","doc":"# Set simple message\n    iex> HipcallSMS.SMS.new() |> HipcallSMS.SMS.text(\"Hello World\")\n    %HipcallSMS.SMS{direction: :outbound, text: \"Hello World\"}\n\n    # Set longer message\n    iex> HipcallSMS.SMS.new() |> HipcallSMS.SMS.text(\"This is a longer message that demonstrates multi-part SMS capability.\")\n    %HipcallSMS.SMS{direction: :outbound, text: \"This is a longer message that demonstrates multi-part SMS capability.\"}\n\n    # Set message with special characters\n    iex> HipcallSMS.SMS.new() |> HipcallSMS.SMS.text(\"Hello! 🎉 Welcome to our service.\")\n    %HipcallSMS.SMS{direction: :outbound, text: \"Hello! 🎉 Welcome to our service.\"}\n\n    # Chain with other functions\n    iex> HipcallSMS.SMS.new()\n    ...> |> HipcallSMS.SMS.from(\"+15551234567\")\n    ...> |> HipcallSMS.SMS.to(\"+15555555555\")\n    ...> |> HipcallSMS.SMS.text(\"Welcome to our service!\")\n    %HipcallSMS.SMS{\n      direction: :outbound,\n      from: \"+15551234567\",\n      to: \"+15555555555\",\n      text: \"Welcome to our service!\"\n    }","ref":"HipcallSMS.SMS.html#text/2-examples"},{"type":"type","title":"HipcallSMS.SMS.to/0","doc":"","ref":"HipcallSMS.SMS.html#t:to/0"},{"type":"function","title":"HipcallSMS.SMS.to/2","doc":"Sets the recipient of the SMS.\n\nThis function sets the `to` field of the SMS struct to the specified phone number.\nThe phone number should be in E.164 format for best compatibility across providers.","ref":"HipcallSMS.SMS.html#to/2"},{"type":"function","title":"Parameters - HipcallSMS.SMS.to/2","doc":"- `sms` - The SMS struct to modify\n- `to` - The recipient phone number (E.164 format recommended)","ref":"HipcallSMS.SMS.html#to/2-parameters"},{"type":"function","title":"Returns - HipcallSMS.SMS.to/2","doc":"The updated SMS struct with the `to` field set.","ref":"HipcallSMS.SMS.html#to/2-returns"},{"type":"function","title":"Examples - HipcallSMS.SMS.to/2","doc":"# Set recipient with E.164 format\n    iex> HipcallSMS.SMS.new() |> HipcallSMS.SMS.to(\"+15555555555\")\n    %HipcallSMS.SMS{direction: :outbound, to: \"+15555555555\"}\n\n    # Set recipient with international format\n    iex> HipcallSMS.SMS.new() |> HipcallSMS.SMS.to(\"+33123456789\")\n    %HipcallSMS.SMS{direction: :outbound, to: \"+33123456789\"}\n\n    # Chain with other functions\n    iex> HipcallSMS.SMS.new()\n    ...> |> HipcallSMS.SMS.from(\"+15551234567\")\n    ...> |> HipcallSMS.SMS.to(\"+15555555555\")\n    %HipcallSMS.SMS{\n      direction: :outbound,\n      from: \"+15551234567\",\n      to: \"+15555555555\"\n    }","ref":"HipcallSMS.SMS.html#to/2-examples"},{"type":"extras","title":"HipcallSMS","doc":"# HipcallSMS\n\n[![Hex.pm Version](https://img.shields.io/hexpm/v/hipcall_sms)](https://hex.pm/packages/hipcall_sms)\n[![Hex.pm Download Total](https://img.shields.io/hexpm/dt/hipcall_sms)](https://hex.pm/packages/hipcall_sms)\n\nFind out what the website is built with using this package.","ref":"readme.html"},{"type":"extras","title":"Installation - HipcallSMS","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `hipcall_sms` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:hipcall_sms, \"~> 0.2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - HipcallSMS","doc":"You can configure providers in your `config.exs`:\n\n```\nconfig :hipcall_sms,\n  adapter: HipcallSMS.Adapters.Telnyx,\n  telnyx_api_key: {:system, \"TELNYX_API_KEY\"},\n  twilio_account_sid: {:system, \"TWILIO_ACCOUNT_SID\"},\n  twilio_auth_token: {:system, \"TWILIO_AUTH_TOKEN\"},\n  iletimerkezi_key: {:system, \"ILETIMERKEZI_KEY\"},\n  iletimerkezi_hash: {:system, \"ILETIMERKEZI_HASH\"}\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Use - HipcallSMS","doc":"Documentation for using, please check the `HipcallSMS` module.","ref":"readme.html#use"},{"type":"extras","title":"Example - HipcallSMS","doc":"```elixir\n# Create and send an SMS\nsms =\n  HipcallSMS.SMS.new()\n  |> HipcallSMS.SMS.from(\"+15551234567\")\n  |> HipcallSMS.SMS.to(\"+15555555555\")\n  |> HipcallSMS.SMS.text(\"Hello from HipcallSMS!\")\n\nHipcallSMS.deliver(sms)\n\n# Or with configuration override\nconfig = [\n  adapter: HipcallSMS.Adapters.Twilio,\n  account_sid: \"your_account_sid\",\n  auth_token: \"your_auth_token\"\n]\n\nHipcallSMS.deliver(sms, config)\n\n# Quick send\nHipcallSMS.send_sms(\"+15551234567\", \"+15555555555\", \"Hello!\")\n```","ref":"readme.html#example"},{"type":"extras","title":"Hipcall - HipcallSMS","doc":"All [Hipcall](https://www.hipcall.com/en/) libraries:\n\n- [HipcallDisposableEmail](https://github.com/hipcall/hipcall_disposable_email) - Simple library checking the email's domain is disposable or not.\n- [HipcallDeepgram](https://github.com/hipcall/hipcall_deepgram) - Unofficial Deepgram API Wrapper written in Elixir.\n- [HipcallOpenai](https://github.com/hipcall/hipcall_openai) - Unofficial OpenAI API Wrapper written in Elixir.\n- [HipcallWhichtech](https://github.com/hipcall/hipcall_whichtech) - Find out what the website is built with.","ref":"readme.html#hipcall"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.3.0 (2025-06-06) - Changelog","doc":"- Add `get_balance` function.","ref":"changelog.html#v0-3-0-2025-06-06"},{"type":"extras","title":"v0.2.0 (2025-06-06) - Changelog","doc":"- Add Telnyx\n- Add Twilio\n- Add Iletimerkezi\n- Improve tests \n- Improve Github Actions","ref":"changelog.html#v0-2-0-2025-06-06"},{"type":"extras","title":"v0.1.0 (2025-04-26) - Changelog","doc":"- Create structure","ref":"changelog.html#v0-1-0-2025-04-26"},{"type":"extras","title":"LICENSE","doc":"Copyright 2024 Hipcall LTD\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}